@@ -2,6 +2,7 @@
 
 # standard lib imports
 from enum import Enum
+import errno
 import signal
 from typing import Optional
 import threading
@@ -17,6 +18,8 @@ import jack
 from patshared import (
     PortType, JackMetadatas, JackMetadata, CustomNames,
     TransportPosition, TransportWanted)
+from jack_wa import (
+    list_all_connections, list_ports, set_port_registration_callback)
 
 # local imports
 from .jack_bases import (
@@ -491,36 +494,39 @@ class PatchEngine:
         self.peo.send_transport_position(transport_position)
     
     def connect_ports(self, port_out_name: str, port_in_name: str,
-                      disconnect=False):
+                      disconnect=False) -> bool:
         if (self.alsa_mng is not None
                 and port_out_name.startswith(':ALSA_OUT:')):
-            self.alsa_mng.connect_ports(
+            return self.alsa_mng.connect_ports(
                 port_out_name, port_in_name, disconnect=disconnect)
-            return
 
         if self.client is None:
-            return
+            return False
 
         if disconnect:
             try:
                 self.client.disconnect(port_out_name, port_in_name)
             except jack.JackErrorCode:
                 # ports already disconnected
-                ...
+                return False
             except BaseException as e:
                 _logger.warning(
                     f"Failed to disconnect '{port_out_name}' "
                     f"from '{port_in_name}'\n{str(e)}")
-        else:
-            try:
-                self.client.connect(port_out_name, port_in_name)
-            except jack.JackErrorCode:
-                # ports already connected
-                ...
-            except BaseException as e:
-                _logger.warning(
-                    f"Failed to connect '{port_out_name}' "
-                    f"to '{port_in_name}'\n{str(e)}")
+            return True
+
+        try:
+            self.client.connect(port_out_name, port_in_name)
+        except jack.JackErrorCode as e:
+            # ports already connected
+            if e.code is not errno.EEXIST:
+                return False
+        except BaseException as e:
+            _logger.warning(
+                f"Failed to connect '{port_out_name}' "
+                f"to '{port_in_name}'\n{str(e)}")
+            return False
+        return True
     
     def set_buffer_size(self, blocksize: int):
         if self.client is None:
@@ -642,7 +648,7 @@ class PatchEngine:
                 self.patch_event_queue.add(
                     PatchEvent.CLIENT_REMOVED, name)
             
-        @self.client.set_port_registration_callback
+        @set_port_registration_callback(self.client) # type:ignore
         def port_registration(port: jack.Port, register: bool):
             port_type = PortType.NULL
             if port.is_audio:
@@ -762,7 +768,7 @@ class PatchEngine:
             return
 
         #get all currents Jack ports and connections
-        for port in self.client.get_ports():
+        for port in list_ports(self.client):
             flags = jack._lib.jack_port_flags(port._ptr) #type:ignore
             port_name = port.name
             port_uuid = port.uuid
@@ -783,7 +789,7 @@ class PatchEngine:
                 continue
 
             # this port is output, list its connections
-            for conn_port in self.client.get_all_connections(port):
+            for conn_port in list_all_connections(self.client, port):
                 self.connections.append((port_name, conn_port.name))
         
         for client_name in client_names:
@@ -1018,19 +1024,19 @@ class PatchEngine:
                     continue
 
                 mdata_pretty_name = jack_pretty_name(client_uuid)
-                pretty_name = self.custom_names.custom_group(client_name)
-                if pretty_name == mdata_pretty_name:
+                custom_name = self.custom_names.custom_group(client_name)
+                if custom_name == mdata_pretty_name:
                     self._set_jack_pretty_name(client_uuid, '')
-                    
-            for port in self.client.get_ports():
+            
+            for port in list_ports(self.client):
                 port_uuid = port.uuid
                 if port_uuid not in self.uuid_pretty_names:
                     continue
                 
                 port_name = port.name
                 mdata_pretty_name = jack_pretty_name(port_uuid)
-                pretty_name = self.custom_names.custom_port(port_name)
-                if pretty_name == mdata_pretty_name:
+                custom_name = self.custom_names.custom_port(port_name)
+                if custom_name == mdata_pretty_name:
                     self._set_jack_pretty_name(port_uuid, '')
 
             self.uuid_pretty_names.clear()
