@@ -1,17 +1,22 @@
 
+# Imports from standard library
 import os
 import socket
 import sys
-import time
-from typing import TYPE_CHECKING
-from PyQt5.QtCore import QObject, QProcess, QTimer
-from PyQt5.QtWidgets import QApplication
-try:
-    from liblo import Address
-except ImportError:
-    from pyliblo3 import Address
+from typing import TYPE_CHECKING, Optional
+import logging
+import json
 
+# third party imports
+from qtpy.QtCore import QObject, QProcess, QTimer
+from qtpy.QtWidgets import QApplication
+
+# Imports from src/shared
+from osclib import Address, get_free_osc_port, verified_address
 import ray
+import osc_paths.ray as r
+
+# Local imports
 from gui_server_thread import GuiServerThread
 from gui_tools import CommandLineArgs, ErrDaemon, _translate
 
@@ -19,6 +24,59 @@ if TYPE_CHECKING:
     from .gui_session import SignaledSession
 
 
+_logger = logging.getLogger(__name__)
+
+
+def _get_port_gui_free() -> Optional[int]:
+    MULTI_DAEMON_FILE = '/tmp/RaySession/multi-daemon.json'
+    try:
+        with open(MULTI_DAEMON_FILE, 'r') as f:
+            json_list = json.load(f)
+    except:
+        return
+    
+    if not isinstance(json_list, list):
+        return
+    
+    for dmn in json_list:
+        if not isinstance(dmn, dict):
+            continue
+        
+        port = dmn.get('port')
+        if not isinstance(port, int):
+            continue
+        
+        if (dmn.get('root') == CommandLineArgs.session_root
+                and dmn.get('user') == os.getenv('USER')
+                and not dmn.get('not_default')):
+            pid = dmn.get('pid')
+            if not isinstance(pid, int) or not pid:
+                continue
+            try:
+                os.kill(pid, 0)
+            except ProcessLookupError:
+                continue
+            
+            if not dmn.get('has_gui') == 3:
+                return port
+
+            local_gui_pids = dmn.get('local_gui_pids')
+
+            has_local_gui = False
+            if isinstance(local_gui_pids, list):
+                for pid in local_gui_pids:
+                    if isinstance(pid, int):
+                        try:
+                            os.kill(pid, 0)
+                        except ProcessLookupError:
+                            continue
+                        else:
+                            has_local_gui = True
+                            break
+            
+            if not has_local_gui:
+                return port
+
 class DaemonManager(QObject):
     def __init__(self, session: 'SignaledSession'):
         QObject.__init__(self)
@@ -28,9 +86,9 @@ class DaemonManager(QObject):
 
         self._process = QProcess()
 
-        if ray.QT_VERSION >= (5, 6):
-            self._process.errorOccurred.connect(self._error_in_process)
-        self._process.setProcessChannelMode(QProcess.ForwardedChannels)
+        self._process.errorOccurred.connect(self._error_in_process)
+        self._process.setProcessChannelMode(
+            QProcess.ProcessChannelMode.ForwardedChannels)
 
         self._announce_timer = QTimer()
         self._announce_timer.setInterval(2000)
@@ -57,9 +115,10 @@ class DaemonManager(QObject):
         self.main_win.daemon_crash()
 
     def _change_url(self, new_url: str):
-        try:
-            self.set_osc_address(ray.get_liblo_address(new_url))
-        except BaseException:
+        addr = verified_address(new_url)
+        if isinstance(addr, Address):
+            self.set_osc_address(addr)
+        else:
             return
 
         self._call_daemon()
@@ -74,11 +133,11 @@ class DaemonManager(QObject):
 
         server = GuiServerThread.instance()
         if not server:
-            sys.stderr.write(
-                'GUI can not call daemon, GUI OSC server is missing.\n')
+            _logger.error(
+                'GUI can not call daemon, GUI OSC server is missing.')
             return
 
-        server.announce()
+        server.announce(self.address)
 
     def _show_daemon_url_window(self):
         self.signaler.daemon_url_request.emit(ErrDaemon.NO_ERROR, self.url)
@@ -91,12 +150,13 @@ class DaemonManager(QObject):
             sys.stderr.write(
                 _translate(
                     'error',
-                    "No announce from ray-daemon. RaySession can't works. Sorry.\n"))
+                    "No announce from ray-daemon." 
+                    "RaySession can't works. Sorry.\n"))
             QApplication.quit()
 
     def _receive_announce(
-            self, src_addr: Address, version: str, server_status: int,
-            options: int, session_root: str, is_net_free: int):
+            self, src_addr: Address, version: str, server_status: ray.ServerStatus,
+            options: ray.Option, session_root: str, is_net_free: int):
         self._announce_timer.stop()
 
         if version.split('.')[:2] != ray.VERSION.split('.')[:2]:
@@ -120,7 +180,7 @@ class DaemonManager(QObject):
             return
 
         if (CommandLineArgs.out_daemon
-                and server_status != ray.ServerStatus.OFF):
+                and server_status is not ray.ServerStatus.OFF):
             self.signaler.daemon_url_request.emit(ErrDaemon.NOT_OFF, self.url)
             self.disannounce(src_addr)
             return
@@ -132,19 +192,21 @@ class DaemonManager(QObject):
         self.session_root = session_root
         CommandLineArgs.change_session_root(self.session_root)
 
-        self._is_nsm_locked = options & ray.Option.NSM_LOCKED
+        self._is_nsm_locked = ray.Option.NSM_LOCKED in options
 
         if self._is_nsm_locked:
             if self.main_win is not None:
                 self.main_win.set_nsm_locked(True)
         elif CommandLineArgs.under_nsm:
             server = GuiServerThread.instance()
-            server.to_daemon('/ray/server/set_nsm_locked')
+            if server is not None:
+                server.to_daemon(r.server.SET_NSM_LOCKED)
 
         if self.main_win is not None and self.main_win.waiting_for_patchbay:
             self.main_win.waiting_for_patchbay = False
             server = GuiServerThread.instance()
-            server.to_daemon('/ray/server/ask_for_patchbay')
+            if server is not None:
+                server.to_daemon(r.server.ASK_FOR_PATCHBAY, '')
 
         self.signaler.daemon_announce_ok.emit()
         self.session.set_daemon_options(options)
@@ -152,13 +214,14 @@ class DaemonManager(QObject):
     def finish_init(self):
         self.main_win = self.session.main_win
 
-    def disannounce(self, address=None):
+    def disannounce(self, address: None | Address =None):
         if not address:
             address = self.address
 
         if address:
             server = GuiServerThread.instance()
-            server.disannounce(address)
+            if server is not None:
+                server.disannounce(address)
 
         self._port = None
         self.url = ''
@@ -183,40 +246,32 @@ class DaemonManager(QObject):
             return
 
         if not CommandLineArgs.force_new_daemon:
-            ray_control_process = QProcess()
-            ray_control_process.start(
-                "ray_control", ['get_port_gui_free', CommandLineArgs.session_root])
-            ray_control_process.waitForFinished(2000)
+            port = _get_port_gui_free()
+            if port is not None:
+                self.address = Address(port)
+                self._port = self.address.port
+                self.url = self.address.url
+                self.launched_before = True
+                self.is_local = True
+                self._call_daemon()
+                sys.stderr.write(
+                    "\033[92m%s\033[0m\n" % (
+                        _translate('GUI_daemon',
+                                    "Connecting GUI to existing ray-daemon port %i")
+                        % self._port))
 
-            if ray_control_process.exitCode() == 0:
-                port_str_lines = \
-                    ray_control_process.readAllStandardOutput().data().decode('utf-8')
-                port_str = port_str_lines.partition('\n')[0]
-
-                if port_str and port_str.isdigit():
-                    self.address = Address(int(port_str))
-                    self._port = self.address.port
-                    self.url = self.address.url
-                    self.launched_before = True
-                    self.is_local = True
-                    self._call_daemon()
-                    sys.stderr.write(
-                        "\033[92m%s\033[0m\n" % (
-                            _translate('GUI_daemon',
-                                       "Connecting GUI to existing ray-daemon port %i")
-                            % self._port))
-
-                    if CommandLineArgs.start_session:
-                        server = GuiServerThread.instance()
-                        if server:
-                            server.send(self.address, '/ray/server/open_session',
-                                        CommandLineArgs.start_session)
-                    return
+                if CommandLineArgs.start_session:
+                    server = GuiServerThread.instance()
+                    if server:
+                        server.send(self.address, r.server.OPEN_SESSION,
+                                    CommandLineArgs.start_session)
+                return
 
         server = GuiServerThread.instance()
-        if not server:
-            sys.stderr.write(
-                "impossible for GUI to launch daemon. server missing.\n")
+        if server is None:
+            _logger.error(
+                "impossible for GUI to launch daemon. server is missing.")
+            return
 
         # start process
         arguments = ['--gui-url', str(server.url),
@@ -234,6 +289,11 @@ class DaemonManager(QObject):
             arguments.append('--debug')
         elif CommandLineArgs.no_client_messages:
             arguments.append('--no-client-messages')
+        
+        if CommandLineArgs.info:
+            arguments += ['--info', CommandLineArgs.info]
+        if CommandLineArgs.dbg:
+            arguments += ['--dbg', CommandLineArgs.dbg]
 
         if CommandLineArgs.config_dir:
             arguments.append('--config-dir')
@@ -249,12 +309,13 @@ class DaemonManager(QObject):
             return
 
         server = GuiServerThread.instance()
-        server.to_daemon('/ray/server/quit')
+        if server is not None:
+            server.to_daemon(r.server.QUIT)
         QTimer.singleShot(50, QApplication.quit)
 
     def set_new_osc_address(self):
         if not (self.address or self._port):
-            self._port = ray.get_free_osc_port()
+            self._port = get_free_osc_port()
             self.address = Address(self._port)
 
     def is_announced(self):
