@@ -1,27 +1,32 @@
+
+# Imports from standard library
 import argparse
 import os
 from pathlib import Path
 import sys
-from typing import TYPE_CHECKING
-from PyQt5.QtCore import QSettings, QSize, QFile, QObject, pyqtSignal
-from PyQt5.QtWidgets import QApplication, QWidget
-from PyQt5.QtGui import QIcon, QPixmap, QPalette
-try:
-    from liblo import Address
-except ImportError:
-    from pyliblo3 import Address
+import logging
+from typing import TYPE_CHECKING, Optional
 
+# third party imports
+from qtpy.QtCore import QSettings, QFile
+from qtpy.QtWidgets import QApplication, QWidget
+from qtpy.QtGui import QIcon, QPixmap, QPalette
+
+# Imports from src/shared
+from osclib import Address, verified_address, verified_address_from_port
 import ray
 
 if TYPE_CHECKING:
     from gui_signaler import Signaler
 
+
+_logger = logging.getLogger(__name__)
 _translate = QApplication.translate
 
-_RAY_ICONS_CACHE_LIGHT = {}
-_RAY_ICONS_CACHE_DARK = {}
-_APP_ICONS_CACHE_LIGHT = {}
-_APP_ICONS_CACHE_DARK = {}
+_ray_icons_cache_light = {}
+_ray_icons_cache_dark = {}
+_app_icons_cache_light = {}
+_app_icons_cache_dark = {}
 
 class RS:
     settings = QSettings()
@@ -39,7 +44,7 @@ class RS:
     HD_StartupRecentSessions = 0x080
     HD_ArdourConversion = 0x100
     
-    _signaler: 'Signaler' = None
+    _signaler: 'Optional[Signaler]' = None
     
     @classmethod
     def set_settings(cls, settings):
@@ -47,7 +52,7 @@ class RS:
         cls.settings = settings
 
     @classmethod
-    def is_hidden(cls, hideable_dialog: int)->bool:
+    def is_hidden(cls, hideable_dialog: int) -> bool:
         hidden_dialogs = cls.settings.value('hidden_dialogs', 0, type=int)
         return bool(hidden_dialogs & hideable_dialog)
 
@@ -67,7 +72,7 @@ class RS:
 
     @classmethod
     def reset_hiddens(cls):
-        cls.settings.setValue('hidden_dialogs', 0)
+        cls.settings.setValue('hidden_dialogs', 0x00)
         if cls._signaler is not None:
             cls._signaler.hiddens_changed.emit(0)
         
@@ -87,35 +92,48 @@ class ErrDaemon:
     WRONG_VERSION = -6
 
 
-class RayAbstractIcon(QIcon):
-    def __init__(self, icon_name: str, dark=False):
-        QIcon.__init__(self)
-        breeze = 'breeze-dark' if dark else 'breeze'
-        self.addFile(':scalable/%s/%s' % (breeze, icon_name), QSize(22, 22))
-        self.addPixmap(
-            QPixmap(
-                ':scalable/%s/disabled/%s' %
-                (breeze, icon_name)), QIcon.Disabled, QIcon.Off)
-
-
-def RayIcon(icon_name: str, dark=False) -> RayAbstractIcon:
-    if dark and icon_name in _RAY_ICONS_CACHE_DARK.keys():
-        return _RAY_ICONS_CACHE_DARK[icon_name]
-    if not dark and icon_name in _RAY_ICONS_CACHE_LIGHT.keys():
-        return _RAY_ICONS_CACHE_LIGHT[icon_name]
+def ray_icon(icon_name: str, dark=False) -> QIcon:
+    if dark and icon_name in _ray_icons_cache_dark.keys():
+        return _ray_icons_cache_dark[icon_name]
+    if not dark and icon_name in _ray_icons_cache_light.keys():
+        return _ray_icons_cache_light[icon_name]
+    
+    icon = QIcon()
+    breeze = 'breeze-dark' if dark else 'breeze'
+    icon.addPixmap(
+        QPixmap(f':/scalable/{breeze}/{icon_name}.svg'),
+        QIcon.Mode.Normal, QIcon.State.On)
+    icon.addPixmap(
+        QPixmap(f':/scalable/{breeze}/disabled/{icon_name}.svg'),
+        QIcon.Mode.Disabled, QIcon.State.Off)
     
-    icon = RayAbstractIcon(icon_name, dark)
     if dark:
-        _RAY_ICONS_CACHE_DARK[icon_name] = icon
+        _ray_icons_cache_dark[icon_name] = icon
     else:
-        _RAY_ICONS_CACHE_LIGHT[icon_name] = icon
+        _ray_icons_cache_light[icon_name] = icon
     
     return icon
 
 
+def verified_address_arg(arg: str) -> Address:
+    addr_or_msg = verified_address(arg)
+    if isinstance(addr_or_msg, Address):
+        return addr_or_msg
+    raise argparse.ArgumentTypeError(addr_or_msg)
+
+def verified_address_from_port_arg(arg: str) -> Address:
+    if not arg.isdigit():
+        raise argparse.ArgumentTypeError(arg)
+    
+    addr_or_msg = verified_address_from_port(int(arg))
+    if isinstance(addr_or_msg, Address):
+        return addr_or_msg
+    raise argparse.ArgumentTypeError(addr_or_msg)
+
+
 class CommandLineArgs(argparse.Namespace):
-    daemon_url: Address = None
-    daemon_port: Address = None
+    daemon_url: Optional[Address] = None
+    daemon_port: Optional[Address] = None
     out_daemon = False
     session_root: str = ''
     config_dir = ''
@@ -129,6 +147,8 @@ class CommandLineArgs(argparse.Namespace):
     session_root = ''
     start_session = ''
     force_new_daemon = False
+    info = ''
+    dbg = ''
 
     @classmethod
     def eat_attributes(cls, parsed_args):
@@ -143,17 +163,17 @@ class CommandLineArgs(argparse.Namespace):
             cls.force_new_daemon = True
 
         if cls.config_dir and not os.access(cls.config_dir, os.W_OK):
-            sys.stderr.write(
-                '%s is not a writable config dir, try another one\n'
-                % cls.config_dir)
+            _logger.error(
+                f'{cls.config_dir} is not a writable config dir, '
+                'try another one !')
             sys.exit(1)
 
         if os.getenv('NSM_URL'):
+            nsm_url = os.getenv('NSM_URL', '')
             try:
-                cls.NSM_URL = ray.get_liblo_address(os.getenv('NSM_URL'))
+                cls.NSM_URL = verified_address_arg(nsm_url)
             except BaseException:
-                sys.stderr.write('%s is not a valid NSM_URL\n'
-                                 % os.getenv('NSM_URL'))
+                _logger.error(f'{nsm_url} is not a valid NSM_URL')
                 sys.exit(1)
 
             cls.under_nsm = True
@@ -175,45 +195,56 @@ class ArgParser(argparse.ArgumentParser):
                 'help',
                 'A session manager based on the Non-Session-Manager API '
                 + 'for sound applications.'))
-        self.add_argument('--daemon-url', '-u', type=ray.get_liblo_address,
-                          help=_translate('help',
-                                          'connect to this daemon url'))
-        self.add_argument('--daemon-port', '-p',
-                          type=ray.get_liblo_address_from_port,
-                          help=_translate('help',
-                                          'connect to this daemon port'))
-        self.add_argument('--out-daemon', action='store_true',
-                          help=argparse.SUPPRESS)
-        self.add_argument('--session-root', '-r', type=str,
-                          help=_translate(
-                              'help', 'Use this folder as root for sessions'))
-        self.add_argument('--start-session', '-s', type=str,
-                          help=_translate('help',
-                                          'Open this session at startup'))
-        self.add_argument('--config-dir', '-c', type=str, default='',
-                          help=_translate('help', 'use a custom config dir'))
-        self.add_argument('--debug', '-d', action='store_true',
-                          help=_translate('help', 'display OSC messages'))
-        self.add_argument('--debug-only', '-do', action='store_true',
-                          help=_translate('help',
-                                          'debug without client messages'))
-        self.add_argument('---no-client-messages', '-ncm', action='store_true',
-                          help=_translate('help',
-                                          'do not print client messages'))
+        self.add_argument(
+            '--daemon-url', '-u', type=verified_address_arg,
+            help=_translate('help', 'connect to this daemon url'))
+        self.add_argument(
+            '--daemon-port', '-p',
+            type=verified_address_from_port_arg,
+            help=_translate('help', 'connect to this daemon port'))
+        self.add_argument(
+            '--out-daemon', action='store_true', help=argparse.SUPPRESS)
+        self.add_argument(
+            '--session-root', '-r', type=str,
+            help=_translate('help', 'Use this folder as root for sessions'))
+        self.add_argument(
+            '--start-session', '-s', type=str,
+            help=_translate('help', 'Open this session at startup'))
+        self.add_argument(
+            '--config-dir', '-c', type=str, default='',
+            help=_translate('help', 'use a custom config dir'))
+        # old arg, do nothing, is kept for backward compatibility
+        self.add_argument(
+            '--debug', '-d', action='store_true', help=argparse.SUPPRESS)
+        # old arg, do nothing, is kept for backward compatibility
+        self.add_argument(
+            '--debug-only', '-do', action='store_true',
+            help=argparse.SUPPRESS)
+        self.add_argument(
+            '---no-client-messages', '-ncm', action='store_true',
+            help=_translate('help', 'do not print client messages'))
+        self.add_argument(
+            '-info', '--info', type=str, default='',
+            help="set the log infos for specific modules, separated with ':'")
+        self.add_argument(
+            '-dbg', '--dbg', type=str, default='',
+            help="set the log debug for specific modules, separated with ':'")
         self.add_argument(
             '--force-new-daemon', '-fnd', action='store_true',
-            help=_translate('help', 'prevent to attach to an already running daemon'))
-        self.add_argument('--net-session-root', type=str, default='',
-                          help=argparse.SUPPRESS)
-        self.add_argument('--net-daemon-id', type=int, default=0,
-                          help=argparse.SUPPRESS)
-        self.add_argument('-v', '--version', action='version',
-                          version=ray.VERSION)
+            help=_translate(
+                'help', 'prevent to attach to an already running daemon'))
+        self.add_argument(
+            '--net-session-root', type=str, default='',
+            help=argparse.SUPPRESS)
+        self.add_argument(
+            '--net-daemon-id', type=int, default=0,
+            help=argparse.SUPPRESS)
+        self.add_argument(
+            '-v', '--version', action='version', version=ray.VERSION)
 
         parsed_args = argparse.ArgumentParser.parse_args(self)
         CommandLineArgs.eat_attributes(parsed_args)
 
-
 def init_gui_tools():
     if CommandLineArgs.under_nsm:
         settings = QSettings('%s/child_sessions'
@@ -228,18 +259,21 @@ def init_gui_tools():
     if not CommandLineArgs.session_root:
         CommandLineArgs.change_session_root(
             settings.value('default_session_root',
-                           ray.DEFAULT_SESSION_ROOT,
+                           str(ray.DEFAULT_SESSION_ROOT),
                            type=str))
 
 def is_dark_theme(widget: QWidget) -> bool:
     return bool(
-        widget.palette().brush(QPalette.Active, QPalette.WindowText).color().lightness()
+        widget.palette().brush(
+            QPalette.ColorGroup.Active,
+            QPalette.ColorRole.WindowText).color().lightness()
         > 128)
 
 def split_in_two(string: str) -> tuple[str, str]:
         middle = int(len(string)/2)
-        sep_indexes = []
+        sep_indexes = list[int]()
         last_was_digit = False
+        sep = ''
 
         for sep in (' ', '-', '_', 'capital'):
             for i in range(len(string)):
@@ -272,17 +306,12 @@ def split_in_two(string: str) -> tuple[str, str]:
             return (string[:best_index], string[best_index+1:])
         return (string[:best_index], string[best_index:])
 
-def dirname(*args) -> str:
-    return os.path.dirname(*args)
-
-def basename(*args) -> str:
-    return os.path.basename(*args)
-
 def get_code_root() -> Path:
-    return Path(__file__).parent.parent.parent
+    return Path(__file__).parents[2]
 
-def server_status_string(server_status: int) -> str:
-    server_status_strings = {
+def server_status_string(server_status: ray.ServerStatus) -> str:
+    SERVER_STATUS_STRINGS = {
+        ray.ServerStatus.INVALID : _translate('server status', "invalid"),
         ray.ServerStatus.OFF     : _translate('server status', "off"),
         ray.ServerStatus.NEW     : _translate('server status', "new"),
         ray.ServerStatus.OPEN    : _translate('server status', "open"),
@@ -301,13 +330,11 @@ def server_status_string(server_status: int) -> str:
         ray.ServerStatus.OUT_SNAPSHOT: _translate('server_status', "snapshot"),
         ray.ServerStatus.SCRIPT  : _translate('server_status', "script")}
 
-    if not 0 <= server_status < len(server_status_strings):
-        return _translate('server status', "invalid")
+    return SERVER_STATUS_STRINGS[server_status]
 
-    return server_status_strings[server_status]
-
-def client_status_string(client_status: int) -> str:
-    client_status_strings = {
+def client_status_string(client_status: ray.ClientStatus) -> str:
+    CLIENT_STATUS_STRINGS = {
+        ray.ClientStatus.INVALID: _translate('client_status', "invalid"),
         ray.ClientStatus.STOPPED: _translate('client status', "stopped"),
         ray.ClientStatus.LAUNCH : _translate('client status', "launch"),
         ray.ClientStatus.OPEN   : _translate('client status', "open"),
@@ -324,38 +351,36 @@ def client_status_string(client_status: int) -> str:
         ray.ClientStatus.SCRIPT : _translate('client_status', 'script'),
         ray.ClientStatus.LOSE   : _translate('client_status', "lose")}
 
-    if not 0 <= client_status < len(client_status_strings):
-        return _translate('client_status', 'invalid')
+    return CLIENT_STATUS_STRINGS[client_status]
 
-    return client_status_strings[client_status]
-
-def error_text(error:int)->str:
+def error_text(error: int) -> str:
     text = ''
     
     if error == ray.Err.SESSION_IN_SESSION_DIR:
         text = _translate(
             'guimsg', 
-            """Can't create session in a dir containing a session
-for better organization.""")
+            "Can't create session in a dir containing a session "
+            "for better organization.")
     
     return text
 
 def get_app_icon(icon_name: str, widget: QWidget) -> QIcon:
     dark = bool(
         widget.palette().brush(
-            2, QPalette.WindowText).color().lightness() > 128)
+            QPalette.ColorGroup.Inactive,
+            QPalette.ColorRole.WindowText).color().lightness() > 128)
     
-    if dark and icon_name in _APP_ICONS_CACHE_DARK.keys():
-        return _APP_ICONS_CACHE_DARK[icon_name]
-    if not dark and icon_name in _APP_ICONS_CACHE_LIGHT.keys():
-        return _APP_ICONS_CACHE_LIGHT[icon_name]
+    if dark and icon_name in _app_icons_cache_dark.keys():
+        return _app_icons_cache_dark[icon_name]
+    if not dark and icon_name in _app_icons_cache_light.keys():
+        return _app_icons_cache_light[icon_name]
     
     icon = QIcon.fromTheme(icon_name)
 
     if icon.isNull():
         for ext in ('svg', 'svgz', 'png'):
-            filename = ":app_icons/%s.%s" % (icon_name, ext)
-            darkname = ":app_icons/dark/%s.%s" % (icon_name, ext)
+            filename = f':app_icons/{icon_name}.{ext}'
+            darkname = f':app_icons/dark/{icon_name}.{ext}'
 
             if dark and QFile.exists(darkname):
                 filename = darkname
@@ -367,9 +392,11 @@ def get_app_icon(icon_name: str, widget: QWidget) -> QIcon:
                 break
 
     if icon.isNull():
-        for path in ('/usr/local', '/usr', '%s/.local' % os.getenv('HOME')):
-            for ext in ('png', 'svg', 'svgz', 'xpm'):
-                filename = "%s/share/pixmaps/%s.%s" % (path, icon_name, ext)
+        usr = Path('/usr')
+        for path in usr / 'local', usr, Path.home() / '.local':
+            for ext in 'png', 'svg', 'svgz', 'xpm':
+                filepath = path / 'share' / 'pixmaps' / f'{icon_name}.{ext}'
+                filename = str(filepath)
                 if QFile.exists(filename):
                     del icon
                     icon = QIcon()
@@ -377,8 +404,8 @@ def get_app_icon(icon_name: str, widget: QWidget) -> QIcon:
                     break
 
     if dark:
-        _APP_ICONS_CACHE_DARK[icon_name] = icon
+        _app_icons_cache_dark[icon_name] = icon
     else:
-        _APP_ICONS_CACHE_LIGHT[icon_name] = icon
+        _app_icons_cache_light[icon_name] = icon
 
     return icon
