@@ -1,22 +1,36 @@
 
+# Imports from standard library
 import os
+from pathlib import Path
 import shutil
 import time
+from typing import TYPE_CHECKING, Optional
 
-from PyQt5.QtWidgets import (QApplication, QTreeWidget, QTreeWidgetItem,
+# third party imports
+from qtpy.QtWidgets import (QApplication, QTreeWidget, QTreeWidgetItem,
                              QDialogButtonBox, QMenu, QMessageBox)
-from PyQt5.QtGui import QIcon, QCursor
-from PyQt5.QtCore import Qt, QTimer, QDateTime, QLocale, QPoint
-from typing import Optional
+from qtpy.QtGui import QIcon, QCursor
+from qtpy.QtCore import Qt, QTimer, QDateTime, QLocale, QPoint
 
+if TYPE_CHECKING:
+    from qtpy.QtGui import QAction # type:ignore
+else:
+    from qtpy.QtWidgets import QAction
+
+
+# Imports from src/shared
 import ray
+import osc_paths.ray as r
+
+# Local imports
 import child_dialogs
-from gui_tools import CommandLineArgs, RayIcon, is_dark_theme, basename
+from gui_tools import CommandLineArgs, ray_icon, is_dark_theme
 from child_dialogs import ChildDialog
 from client_properties_dialog import ClientPropertiesDialog
 from snapshots_dialog import (
-    Snapshot, SnapGroup, GROUP_MAIN)
+    Snapshot, SnapGroup, SnGroup)
 
+# Import UIs made with Qt-Designer
 import ui.open_session
 
 _translate = QApplication.translate
@@ -36,14 +50,15 @@ CORNER_LISTING = 1
 CORNER_COPY = 2
 CORNER_NOTIFICATION = 3
 
-DATA_SIZE = Qt.UserRole + 1
+DATA_SIZE = Qt.ItemDataRole.UserRole + 1
 
 
 class SessionItem(QTreeWidgetItem):
     def __init__(self, l_list, is_session=False):
         QTreeWidgetItem.__init__(self, l_list)
         self.is_session = is_session
-        self.setTextAlignment(3, Qt.AlignRight | Qt.AlignVCenter)
+        self.setTextAlignment(
+            3, Qt.AlignmentFlag.AlignRight | Qt.AlignmentFlag.AlignVCenter)
 
     def __lt__(self, other: 'SessionItem'):
         if self.childCount() and not other.childCount():
@@ -53,8 +68,8 @@ class SessionItem(QTreeWidgetItem):
             return False
 
         if OpenSessionDialog.sort_by_date:
-            self_date_int = self.data(COLUMN_DATE, Qt.UserRole)
-            other_date_int = other.data(COLUMN_DATE, Qt.UserRole)
+            self_date_int = self.data(COLUMN_DATE, Qt.ItemDataRole.UserRole)
+            other_date_int = other.data(COLUMN_DATE, Qt.ItemDataRole.UserRole)
             if self_date_int is None:
                 if other_date_int is None:
                     return bool(self.text(COLUMN_NAME).lower()
@@ -71,7 +86,7 @@ class SessionItem(QTreeWidgetItem):
 
     def show_conditionnaly(self, string: str) -> bool:
         show = bool(
-            string.lower() in self.data(COLUMN_NAME, Qt.UserRole).lower())
+            string.lower() in self.data(COLUMN_NAME, Qt.ItemDataRole.UserRole).lower())
 
         n = 0
         for i in range(self.childCount()):
@@ -85,7 +100,7 @@ class SessionItem(QTreeWidgetItem):
         return show
 
     def find_item_with(self, string: str) -> 'Optional[SessionItem]':
-        if self.data(COLUMN_NAME, Qt.UserRole) == string:
+        if self.data(COLUMN_NAME, Qt.ItemDataRole.UserRole) == string:
             return self
 
         item = None
@@ -100,8 +115,8 @@ class SessionItem(QTreeWidgetItem):
     def set_notes_icon(self, icon):
         self.setIcon(COLUMN_NOTES, icon)
 
-    def set_scripted(self, script_flags:int, for_child=False):
-        if script_flags == ray.ScriptFile.PREVENT:
+    def set_scripted(self, script_flags: ray.ScriptFile, for_child=False):
+        if script_flags is ray.ScriptFile.PREVENT:
             self.setText(COLUMN_SCRIPTS, "")
         else:
             if for_child:
@@ -114,17 +129,17 @@ class SessionItem(QTreeWidgetItem):
             item.set_scripted(script_flags, for_child=True)
     
     def set_modified_date(self, date_int:int):
-        self.setData(COLUMN_DATE, Qt.UserRole, date_int)
+        self.setData(COLUMN_DATE, Qt.ItemDataRole.UserRole, date_int)
 
         date = QDateTime.fromSecsSinceEpoch(date_int)
         date_string =  date.toString("dd/MM/yy hh:mm")
-        if QLocale.system().country() == QLocale.UnitedStates:
+        if QLocale.system().country() == QLocale.Country.UnitedStates:
             date_string = date.toString("MM/dd/yy hh:mm")
 
         self.setText(COLUMN_DATE, date_string)
             
     def add_modified_date(self, path:str, date_int:int):
-        self_path = self.data(COLUMN_NAME, Qt.UserRole)
+        self_path = self.data(COLUMN_NAME, Qt.ItemDataRole.UserRole)
         if not self_path:
             return
         
@@ -133,7 +148,7 @@ class SessionItem(QTreeWidgetItem):
             return
         
         if path.startswith(self_path + '/'):
-            current_data_date = self.data(COLUMN_DATE, Qt.UserRole)
+            current_data_date = self.data(COLUMN_DATE, Qt.ItemDataRole.UserRole)
             if current_data_date is None:
                 current_data_date = 0
             
@@ -146,13 +161,13 @@ class SessionItem(QTreeWidgetItem):
 
     def set_locked(self, locked:bool):
         if locked:
-            self.setFlags(self.flags() & ~Qt.ItemIsEnabled)
+            self.setFlags(self.flags() & ~Qt.ItemFlag.ItemIsEnabled)
         else:
-            self.setFlags(self.flags() | Qt.ItemIsEnabled)
+            self.setFlags(self.flags() | Qt.ItemFlag.ItemIsEnabled)
 
     # Re-implemented protected Qt function
     def child(self, index: int) -> 'SessionItem':
-        return QTreeWidgetItem.child(self, index)
+        return QTreeWidgetItem.child(self, index) # type:ignore
 
 
 class SessionFolder:
@@ -170,13 +185,13 @@ class SessionFolder:
 
     def make_item(self):
         self.item = SessionItem([self.name, "", "", ""], self.is_session)
-        self.item.setData(COLUMN_NAME, Qt.UserRole, self.path)
+        self.item.setData(COLUMN_NAME, Qt.ItemDataRole.UserRole, self.path)
 
         if self.subfolders:
             self.item.setIcon(COLUMN_NAME, QIcon.fromTheme('folder'))
 
         if not self.is_session:
-            self.item.setFlags(self.item.flags() & ~Qt.ItemIsSelectable)
+            self.item.setFlags(self.item.flags() & ~Qt.ItemFlag.ItemIsSelectable)
 
         for folder in self.subfolders:
             sub_item = folder.make_item()
@@ -188,7 +203,7 @@ class SessionFolder:
         if self.item is None:
             return
         
-        self.item.sortChildren(COLUMN_NAME, Qt.AscendingOrder)
+        self.item.sortChildren(COLUMN_NAME, Qt.SortOrder.AscendingOrder)
         
         for folder in self.subfolders:
             folder.sort_childrens()
@@ -205,7 +220,7 @@ class SaveSessionTemplateDialog(child_dialogs.SaveTemplateSessionDialog):
         child_dialogs.SaveTemplateSessionDialog.__init__(self, parent)
         self._server_will_accept = True
 
-    def _server_status_changed(self, server_status):
+    def _server_status_changed(self, server_status: ray.ServerStatus):
         # server will always accept, whatever the status
         pass
     
@@ -222,7 +237,7 @@ class DuplicateDialog(child_dialogs.NewSessionDialog):
         self.ui.toolButtonFolder.setVisible(False)
         self._original_session_name = ''
     
-    def _server_status_changed(self, server_status):
+    def _server_status_changed(self, server_status: ray.ServerStatus):
         # server will always accept, whatever the status
         pass
     
@@ -258,43 +273,46 @@ class OpenSessionDialog(ChildDialog):
         self._listing_timer_progress_n = 0
         self._listing_timer_progress = QTimer()
         self._listing_timer_progress.setInterval(50)
-        self._listing_timer_progress.timeout.connect(self._listing_timer_progress_timeout)
+        self._listing_timer_progress.timeout.connect(
+            self._listing_timer_progress_timeout)
         self._listing_timer_progress.start()
         self._progress_inverted = False
 
         self.session_menu = QMenu()
-        self.action_duplicate = self.session_menu.addAction(
+        self.action_duplicate: QAction = self.session_menu.addAction(
             QIcon.fromTheme('duplicate'),
             _translate('session_menu', 'Duplicate session'))
-        self.action_save_as_template = self.session_menu.addAction(
+        self.action_save_as_template: QAction = self.session_menu.addAction(
             QIcon.fromTheme('template'),
             _translate('session_menu', 'Save session as template'))
-        self.action_rename = self.session_menu.addAction(
+        self.action_rename: QAction = self.session_menu.addAction(
             QIcon.fromTheme('edit-rename'),
             _translate('session_menu', 'Rename session'))
-        self.action_remove = self.session_menu.addAction(
+        self.action_remove: QAction = self.session_menu.addAction(
             QIcon.fromTheme('remove'),
             _translate('session_menu', 'Remove session'))
 
         dark = is_dark_theme(self)
         self.action_duplicate.setIcon(
-            RayIcon('xml-node-duplicate', dark))
+            ray_icon('xml-node-duplicate', dark))
         self.action_save_as_template.setIcon(
-            RayIcon('document-save-as-template', dark))
+            ray_icon('document-save-as-template', dark))
 
         self.action_rename.triggered.connect(self._ask_for_session_rename)
         self.action_duplicate.triggered.connect(self._ask_for_session_duplicate)
         self.action_save_as_template.triggered.connect(
             self._ask_for_session_save_as_template)
         self.action_remove.triggered.connect(self._ask_for_session_remove)
-        self.ui.toolButtonSessionMenu.setMenu(self.session_menu)
+        self.ui.toolButtonSessionMenu.setMenu(self.session_menu) # type:ignore
         self.ui.toolButtonFolderPreview.clicked.connect(
             self._open_preview_folder)
         
         self.ui.splitterMain.setSizes([240, 800])
         self.ui.stackedWidgetSessionName.set_text('')
         self.ui.previewFrame.setEnabled(False)
-        self.ui.tabWidget.tabBar().setExpanding(True)
+        tabw_tabbar = self.ui.tabWidget.tabBar()
+        if tabw_tabbar is not None:
+            tabw_tabbar.setExpanding(True)
         self.ui.toolButtonFolder.clicked.connect(self._change_root_folder)
         
         self.ui.splitterMain.splitterMoved.connect(
@@ -303,7 +321,7 @@ class OpenSessionDialog(ChildDialog):
             self._session_name_changed)
         self.ui.sessionList.currentItemChanged.connect(
             self._current_item_changed)
-        self.ui.sessionList.setFocus(Qt.OtherFocusReason)
+        self.ui.sessionList.setFocus(Qt.FocusReason.OtherFocusReason) # type:ignore
         self.ui.sessionList.itemDoubleClicked.connect(self._go_if_any)
         self.ui.sessionList.itemClicked.connect(self._deploy_item)
         self.ui.sessionList.customContextMenuRequested.connect(
@@ -314,7 +332,8 @@ class OpenSessionDialog(ChildDialog):
             self._show_client_properties)
         self.ui.listWidgetPreview.add_to_session_request.connect(
             self._add_client_to_current_session)
-        self.ui.buttonBox.button(QDialogButtonBox.Ok).setEnabled(False)
+        self.ui.buttonBox.button(
+            QDialogButtonBox.StandardButton.Ok).setEnabled(False) # type:ignore
         self.ui.currentSessionsFolder.setText(CommandLineArgs.session_root)
         self.ui.checkBoxShowDates.stateChanged.connect(
             self._set_full_sessions_view)
@@ -342,7 +361,7 @@ class OpenSessionDialog(ChildDialog):
         self.signaler.other_session_templated.connect(
             self._session_templated_by_server)
 
-        self.to_daemon('/ray/server/list_sessions', 0)
+        self.to_daemon(r.server.LIST_SESSIONS, 0)
         
         self.ui.groupBoxProgress.setVisible(False)
 
@@ -363,7 +382,7 @@ class OpenSessionDialog(ChildDialog):
         self.folders = list[SessionFolder]()
         self.all_items = []
 
-        self.ui.filterBar.setFocus(Qt.OtherFocusReason)
+        self.ui.filterBar.setFocus(Qt.FocusReason.OtherFocusReason)
         
         # snapshots related
         self.main_snap_group = SnapGroup()
@@ -376,7 +395,7 @@ class OpenSessionDialog(ChildDialog):
         self._set_corner_group(CORNER_HIDDEN)
         
         self.ui.checkBoxSaveCurrentSession.setVisible(
-            self.session.server_status == ray.ServerStatus.READY)
+            self.session.server_status is ray.ServerStatus.READY)
         self.ui.listWidgetPreview.server_status_changed(
             self.session.server_status)
         
@@ -396,11 +415,11 @@ class OpenSessionDialog(ChildDialog):
         
         OpenSessionDialog.set_sort_by_date(full_view)
         root_item = self.ui.sessionList.invisibleRootItem()
-        root_item.sortChildren(COLUMN_NAME, Qt.AscendingOrder)
+        root_item.sortChildren(COLUMN_NAME, Qt.SortOrder.AscendingOrder) # type:ignore
         for folder in self.folders:
             folder.sort_childrens()
         
-    def _server_status_changed(self, server_status):
+    def _server_status_changed(self, server_status: ray.ServerStatus):
         self.ui.toolButtonFolder.setEnabled(
             bool(server_status in (ray.ServerStatus.OFF,
                                    ray.ServerStatus.READY,
@@ -411,13 +430,13 @@ class OpenSessionDialog(ChildDialog):
                 ray.ServerStatus.OFF,
                 ray.ServerStatus.READY) and not self.server_copying)
 
-        if server_status != ray.ServerStatus.OFF:
+        if server_status is not ray.ServerStatus.OFF:
             if self._root_folder_file_dialog is not None:
                 self._root_folder_file_dialog.reject()
             self._root_folder_message_box.reject()
 
         self.ui.checkBoxSaveCurrentSession.setVisible(
-            server_status == ray.ServerStatus.READY)
+            server_status is ray.ServerStatus.READY)
         
         self.ui.listWidgetPreview.server_status_changed(server_status)
 
@@ -442,7 +461,7 @@ class OpenSessionDialog(ChildDialog):
         self.ui.currentSessionsFolder.setText(session_root)
         self.ui.sessionList.clear()
         self.folders.clear()
-        self.to_daemon('/ray/server/list_sessions', 0)
+        self.to_daemon(r.server.LIST_SESSIONS, 0)
 
     def _add_sessions(self, session_names: list[str], out_of_listing=False):
         if not self._listing_sessions and not out_of_listing:
@@ -451,7 +470,8 @@ class OpenSessionDialog(ChildDialog):
             # Check which one is selected and clear all of them. 
             item = self.ui.sessionList.currentItem()
             if item is not None:
-                self._last_selected_session = item.data(COLUMN_NAME, Qt.UserRole)
+                self._last_selected_session = item.data(
+                    COLUMN_NAME, Qt.ItemDataRole.UserRole)
             
             self.folders.clear()
             self.ui.sessionList.clear()
@@ -465,14 +485,18 @@ class OpenSessionDialog(ChildDialog):
             self._set_corner_group(CORNER_HIDDEN)
 
             root_item = self.ui.sessionList.invisibleRootItem()
+            if root_item is None:
+                return
+            
             sess_item = None
             
             if self._last_selected_session:
                 for folder in self.folders:
-                    item = folder.find_item_with(self._last_selected_session)
+                    item = folder.find_item_with(
+                        self._last_selected_session)
                     if item is not None:
-                        self.ui.sessionList.setCurrentItem(item)
-                        self.ui.sessionList.scrollToItem(item)
+                        self.ui.sessionList.setCurrentItem(item) # type:ignore
+                        self.ui.sessionList.scrollToItem(item) # type:ignore
                         break
                 else:
                     self._last_selected_session = ''
@@ -484,13 +508,15 @@ class OpenSessionDialog(ChildDialog):
 
                     for i in range(root_item.childCount()):
                         item = root_item.child(i)
+                        if not isinstance(item, SessionItem):
+                            continue
                         sess_item = item.find_item_with(sess)
                         if sess_item is not None:
                             break
                     
                     if sess_item is not None:
-                        self.ui.sessionList.setCurrentItem(sess_item)
-                        self.ui.sessionList.scrollToItem(sess_item)
+                        self.ui.sessionList.setCurrentItem(sess_item) # type:ignore
+                        self.ui.sessionList.scrollToItem(sess_item) # type:ignore
                         break
                 
             QTimer.singleShot(20, self._resize_session_names_column)
@@ -527,30 +553,33 @@ class OpenSessionDialog(ChildDialog):
 
         for folder in self.folders:
             item = folder.make_item()
-            self.ui.sessionList.addTopLevelItem(item)
+            self.ui.sessionList.addTopLevelItem(item) # type:ignore
 
-        self.ui.sessionList.sortByColumn(COLUMN_NAME, Qt.AscendingOrder)
+        self.ui.sessionList.sortByColumn(
+            COLUMN_NAME, Qt.SortOrder.AscendingOrder) # type:ignore
 
     def _update_filtered_list(self, filt):
         filter_text = self.ui.filterBar.displayText()
         root_item = self.ui.sessionList.invisibleRootItem()
+        if root_item is None:
+            return
 
         ## hide all non matching items
         for i in range(root_item.childCount()):
-            sess_item: SessionItem = root_item.child(i)
+            sess_item: SessionItem = root_item.child(i) # type:ignore
             sess_item.show_conditionnaly(filter_text)
 
         # if selected item not in list, then select the first visible
-        if (not self.ui.sessionList.currentItem()
-                or self.ui.sessionList.currentItem().isHidden()):
+        current_item = self.ui.sessionList.currentItem()
+        if current_item is None or current_item.isHidden():
             for i in range(root_item.childCount()):
                 item = root_item.child(i)
-                if not item.isHidden():
+                if item is not None and not item.isHidden():
                     self.ui.sessionList.setCurrentItem(item)
                     break
 
-        if (not self.ui.sessionList.currentItem()
-                or self.ui.sessionList.currentItem().isHidden()):
+        current_item = self.ui.sessionList.currentItem()
+        if current_item is None or current_item.isHidden():
             self.ui.filterBar.setStyleSheet(
                 "QLineEdit { background-color: red}")
             self.ui.sessionList.setCurrentItem(None)
@@ -570,7 +599,7 @@ class OpenSessionDialog(ChildDialog):
 
         ex_item = current_item
 
-        while not current_item.flags() & Qt.ItemIsSelectable:
+        while not current_item.flags() & Qt.ItemFlag.ItemIsSelectable: # type:ignore
             ex_item = current_item
             QTreeWidget.keyPressEvent(self.ui.sessionList, event)
             current_item = self.ui.sessionList.currentItem()
@@ -578,19 +607,25 @@ class OpenSessionDialog(ChildDialog):
                 self.ui.sessionList.setCurrentItem(start_item)
                 return
 
-    def _current_item_changed(self, item: SessionItem, previous_item: SessionItem):
-        self._has_selection = bool(item and item.data(COLUMN_NAME, Qt.UserRole))
+    def _current_item_changed(
+            self, item: SessionItem, previous_item: SessionItem):
+        self._has_selection = bool(
+            item and item.data(COLUMN_NAME, Qt.ItemDataRole.UserRole))
         
         self.ui.listWidgetPreview.clear()
         self.ui.treeWidgetSnapshots.clear()
         self.ui.labelSessionSize.setText('')
         
         if item is not None and item.is_session:
-            session_full_name = item.data(COLUMN_NAME, Qt.UserRole)
-            self.ui.stackedWidgetSessionName.set_text(basename(session_full_name))
+            session_full_name: str = item.data(
+                COLUMN_NAME, Qt.ItemDataRole.UserRole)
+            self.ui.stackedWidgetSessionName.set_text(
+                Path(session_full_name).name)
             self.ui.previewFrame.setEnabled(True)
             if session_full_name:
-                self.to_daemon('/ray/server/get_session_preview', session_full_name)
+                self.to_daemon(
+                    r.server.GET_SESSION_PREVIEW,
+                    session_full_name)
 
             if item.text(COLUMN_SCRIPTS):
                 self._set_preview_scripted(True)
@@ -619,11 +654,12 @@ class OpenSessionDialog(ChildDialog):
             self.ui.labelPreviewScript.setStyleSheet('')
 
     def _prevent_ok(self):
-        self.ui.buttonBox.button(QDialogButtonBox.Ok).setEnabled(
-            bool(self._server_will_accept and self._has_selection))
+        self.ui.buttonBox.button(
+            QDialogButtonBox.StandardButton.Ok).setEnabled( # type:ignore
+                bool(self._server_will_accept and self._has_selection))
 
     def _show_context_menu(self):
-        item: SessionItem = self.ui.sessionList.currentItem()
+        item: SessionItem = self.ui.sessionList.currentItem() # type:ignore
         if item is None:
             return
 
@@ -631,7 +667,7 @@ class OpenSessionDialog(ChildDialog):
             return
 
         x = QCursor.pos().x()
-        rect = self.ui.sessionList.visualItemRect(item)
+        rect = self.ui.sessionList.visualItemRect(item) # type:ignore
         y = self.ui.sessionList.mapToGlobal(rect.bottomLeft()).y()
         
         self.session_menu.exec(QPoint(x, y+1))
@@ -645,14 +681,16 @@ class OpenSessionDialog(ChildDialog):
         if item is None:
             return
         
-        session_name = item.data(COLUMN_NAME, Qt.UserRole)
-        self.to_daemon('/ray/server/open_file_manager_at',
-                       os.path.join(CommandLineArgs.session_root, session_name))
+        session_name = item.data(COLUMN_NAME, Qt.ItemDataRole.UserRole)
+        self.to_daemon(
+            r.server.OPEN_FILE_MANAGER_AT,
+            os.path.join(CommandLineArgs.session_root, session_name))
 
     def _set_corner_group(self, corner_mode:int):
         self._corner_mode = corner_mode
         self.ui.groupBoxProgress.setVisible(corner_mode != CORNER_HIDDEN)
-        self.ui.pushButtonCancelProgress.setVisible(corner_mode != CORNER_LISTING)
+        self.ui.pushButtonCancelProgress.setVisible(
+            corner_mode != CORNER_LISTING)
 
         if corner_mode == CORNER_LISTING:
             self.ui.labelProgress.setText(
@@ -681,7 +719,7 @@ class OpenSessionDialog(ChildDialog):
         if item is None:
             return
         
-        old_session_name = item.data(COLUMN_NAME, Qt.UserRole)
+        old_session_name = item.data(COLUMN_NAME, Qt.ItemDataRole.UserRole)
         
         if self._pending_action:
             return
@@ -696,7 +734,7 @@ class OpenSessionDialog(ChildDialog):
 
         self._set_pending_action(PENDING_ACTION_DUPLICATE)
         self._session_duplicating = (old_session_name, new_session_name)
-        self.to_daemon('/ray/session/duplicate_only', old_session_name,
+        self.to_daemon(r.session.DUPLICATE_ONLY, old_session_name,
                        new_session_name, CommandLineArgs.session_root)
 
     def _ask_for_session_save_as_template(self):
@@ -707,7 +745,7 @@ class OpenSessionDialog(ChildDialog):
         if self._pending_action:
             return
 
-        session_name = item.data(COLUMN_NAME, Qt.UserRole)
+        session_name = item.data(COLUMN_NAME, Qt.ItemDataRole.UserRole)
 
         dialog = SaveSessionTemplateDialog(self)
         dialog.set_original_session_name(session_name)
@@ -719,7 +757,7 @@ class OpenSessionDialog(ChildDialog):
 
         self._set_pending_action(PENDING_ACTION_TEMPLATE)
         self._session_templating = (session_name, template_name)
-        self.to_daemon('/ray/server/save_session_template',
+        self.to_daemon(r.server.SAVE_SESSION_TEMPLATE,
                        session_name, template_name)
 
     def _ask_for_session_remove(self):
@@ -738,7 +776,7 @@ class OpenSessionDialog(ChildDialog):
         if item is None:
             return
         
-        session_name = item.data(COLUMN_NAME, Qt.UserRole)
+        session_name = item.data(COLUMN_NAME, Qt.ItemDataRole.UserRole)
         full_path = os.path.join(CommandLineArgs.session_root, session_name)
 
         if not os.path.isdir(full_path):
@@ -747,15 +785,17 @@ class OpenSessionDialog(ChildDialog):
         ret = QMessageBox.critical(
             self,
             _translate('open_session', 'Remove session'),
-            _translate('open_session',
-                       '<p>Are you really sure to want to remove the  following session:</p>'
-                       + '<p><strong>%s</strong></p>'
-                       + '<p>This action is irreversible.')
+            _translate(
+                'open_session',
+                '<p>Are you really sure to want to remove '
+                'the following session:</p>'
+                '<p><strong>%s</strong></p>'
+                '<p>This action is irreversible.')
             % session_name,
-            QMessageBox.No | QMessageBox.Yes,
-            QMessageBox.No)
+            QMessageBox.StandardButton.No | QMessageBox.StandardButton.Yes,
+            QMessageBox.StandardButton.No)
         
-        if ret != QMessageBox.Yes:
+        if ret != QMessageBox.StandardButton.Yes:
             return
             
         try:
@@ -767,17 +807,18 @@ class OpenSessionDialog(ChildDialog):
         parent = item.parent()
         if parent is None:
             parent = self.ui.sessionList.invisibleRootItem()
-        parent.removeChild(item)
+        else:
+            parent.removeChild(item)
 
     def _session_name_changed(self, new_name:str):
         item = self.ui.sessionList.currentItem()
         if item is None:
             return
 
-        old_name = item.data(COLUMN_NAME, Qt.UserRole)
+        old_name: str = item.data(COLUMN_NAME, Qt.ItemDataRole.UserRole)
 
         # prevent accidental renaming to same name
-        if basename(old_name) == new_name:
+        if Path(old_name).name == new_name:
             return
         
         if self._pending_action:
@@ -785,7 +826,7 @@ class OpenSessionDialog(ChildDialog):
 
         self._set_pending_action(PENDING_ACTION_RENAME)
         self._session_renaming = (old_name, new_name)
-        self.to_daemon('/ray/server/rename_session', old_name, new_name)
+        self.to_daemon(r.server.RENAME_SESSION, old_name, new_name)
 
     def _parrallel_copy_state(self, session_id:int, state:int):
         if state and self._current_parrallel_copy_id:
@@ -813,7 +854,7 @@ class OpenSessionDialog(ChildDialog):
                 self._set_corner_group(CORNER_HIDDEN)
             return
         
-        self.to_daemon('/ray/server/abort_parrallel_copy',
+        self.to_daemon(r.server.ABORT_PARRALLEL_COPY,
                        self._current_parrallel_copy_id)
 
     def _session_renamed_by_server(self):
@@ -821,9 +862,9 @@ class OpenSessionDialog(ChildDialog):
         self._session_renaming = ('', '')
         current_name = ''
 
-        item = self.ui.sessionList.currentItem()
+        item: Optional[SessionItem] = self.ui.sessionList.currentItem() # type:ignore
         if item is not None:
-            current_name = item.data(COLUMN_NAME, Qt.UserRole)
+            current_name = item.data(COLUMN_NAME, Qt.ItemDataRole.UserRole)
 
         new_long_name = new_name
         if '/' in old_name:
@@ -833,10 +874,15 @@ class OpenSessionDialog(ChildDialog):
             # should rarely happens because rename session is very fast
             # in case session has been renamed but is not selected anymore
             for i in range(self.ui.sessionList.topLevelItemCount()):
-                item: SessionItem = self.ui.sessionList.topLevelItem(i)
+                item: Optional[SessionItem] = \
+                    self.ui.sessionList.topLevelItem(i) # type:ignore
+                if item is None:
+                    continue
+
                 session_item = item.find_item_with(old_name)
                 if session_item is not None:
-                    session_item.setData(COLUMN_NAME, Qt.UserRole, new_long_name)
+                    session_item.setData(
+                        COLUMN_NAME, Qt.ItemDataRole.UserRole, new_long_name)
                     session_item.setText(COLUMN_DATE, new_name)
                     break
             return
@@ -844,7 +890,7 @@ class OpenSessionDialog(ChildDialog):
         if item is None:
             return
 
-        item.setData(COLUMN_NAME, Qt.UserRole, new_long_name)
+        item.setData(COLUMN_NAME, Qt.ItemDataRole.UserRole, new_long_name)
         item.setText(COLUMN_NAME, new_name)
         self.ui.stackedWidgetSessionName.set_text(new_name)
         self._set_pending_action(PENDING_ACTION_NONE)
@@ -859,7 +905,7 @@ class OpenSessionDialog(ChildDialog):
         for folder in self.folders:
             item = folder.find_item_with(new_name)
             if item is not None:
-                self.ui.sessionList.setCurrentItem(item)
+                self.ui.sessionList.setCurrentItem(item) # type:ignore
                 filter_text = self.ui.filterBar.text()
 
                 if filter_text.lower() in new_name.lower():
@@ -871,7 +917,7 @@ class OpenSessionDialog(ChildDialog):
                 while parent_item is not None:
                     parent_item.setExpanded(True)
                     parent_item = parent_item.parent()
-                self.ui.sessionList.scrollToItem(item)
+                self.ui.sessionList.scrollToItem(item) # type:ignore
                 break
 
         self._set_corner_group(CORNER_HIDDEN)
@@ -900,34 +946,45 @@ class OpenSessionDialog(ChildDialog):
         if item.childCount():
             return
 
-        if (self._server_will_accept and self._has_selection
-                and self.ui.sessionList.currentItem().data(
-                    COLUMN_NAME, Qt.UserRole)):
-            self.accept()
+        if (self._server_will_accept and self._has_selection):
+            current_item = self.ui.sessionList.currentItem()
+            if (current_item is not None
+                    and current_item.data(COLUMN_NAME,
+                                          Qt.ItemDataRole.UserRole)):
+                self.accept()
 
-    def _session_preview_update(self):
-        self.ui.plainTextEditNotes.setPlainText(self.session.preview_notes)
+    def _session_preview_update(self, state: int):
+        preview_state = ray.PreviewState(state)
+        
+        if preview_state is ray.PreviewState.NOTES:
+            self.ui.plainTextEditNotes.setPlainText(
+                self.session.preview_notes)
 
-        for pv_client in self.session.preview_client_list:
-            client_slot = self.ui.listWidgetPreview.create_client_widget(pv_client)
-            client_slot.set_launched(
-                pv_client.client_id in self.session.preview_started_clients)
+        elif preview_state is ray.PreviewState.CLIENTS:
+            for pv_client in self.session.preview_client_list:
+                client_slot = self.ui.listWidgetPreview \
+                    .create_client_widget(pv_client)
+                client_slot.set_launched(
+                    pv_client.client_id
+                    in self.session.preview_started_clients)
         
-        self.main_snap_group.snapshots.clear()
-        self._add_snapshots(self.session.preview_snapshots)
+        elif preview_state is ray.PreviewState.SNAPSHOTS:
+            self.main_snap_group.snapshots.clear()
+            self._add_snapshots(self.session.preview_snapshots)
         
-        locale = QLocale()
-        self.ui.labelSessionSize.setText(
-            locale.formattedDataSize(self.session.preview_size))
-        
-        # store size in item
-        item = self.ui.sessionList.currentItem()
-        if item is not None:
-            item.setData(COLUMN_NAME, DATA_SIZE, self.session.preview_size)
-            self._set_preview_scripted(
-                bool(item.text(COLUMN_SCRIPTS)))
-        else:
-            self._set_preview_scripted(False)
+        elif preview_state is ray.PreviewState.FOLDER_SIZE:
+            locale = QLocale()
+            self.ui.labelSessionSize.setText(
+                locale.formattedDataSize(self.session.preview_size))
+            
+            # store size in item
+            item = self.ui.sessionList.currentItem()
+            if item is not None:
+                item.setData(COLUMN_NAME, DATA_SIZE, self.session.preview_size)
+                self._set_preview_scripted(
+                    bool(item.text(COLUMN_SCRIPTS)))
+            else:
+                self._set_preview_scripted(False)
                 
         self._update_session_menu()
 
@@ -974,21 +1031,20 @@ class OpenSessionDialog(ChildDialog):
         self.ui.treeWidgetSnapshots.clear()
 
         for snapshot in self.main_snap_group.snapshots:
-            item = snapshot.make_item(GROUP_MAIN)
+            item = snapshot.make_item(SnGroup.MAIN)
             self.ui.treeWidgetSnapshots.addTopLevelItem(item)
 
-        #self.ui.buttonBox.button(QDialogButtonBox.Ok).setEnabled(False)
         self.ui.treeWidgetSnapshots.clearSelection()
 
     def _update_session_details(self, session_name: str,
                                 has_notes: int, modified: int, locked: int):
         for i in range(self.ui.sessionList.topLevelItemCount()):
-            item: SessionItem = self.ui.sessionList.topLevelItem(i)
+            item: SessionItem = self.ui.sessionList.topLevelItem(i) # type:ignore
             session_item = item.find_item_with(session_name)
             if session_item is not None:
                 if has_notes:
                     session_item.set_notes_icon(
-                        RayIcon('notes', is_dark_theme(self)))
+                        ray_icon('notes', is_dark_theme(self)))
                 
                 # we add directly date to top item
                 # this way folder also read the last date
@@ -997,19 +1053,19 @@ class OpenSessionDialog(ChildDialog):
                 session_item.set_locked(bool(locked))
                 break
 
-    def _scripted_dir(self, dir_name, script_flags):
+    def _scripted_dir(self, dir_name: str, script_flags: int):
         if dir_name == '':
             # means that all the session root directory is scripted
             for i in range(self.ui.sessionList.topLevelItemCount()):
-                item: SessionItem = self.ui.sessionList.topLevelItem(i)
-                item.set_scripted(script_flags)
+                item: SessionItem = self.ui.sessionList.topLevelItem(i) # type:ignore
+                item.set_scripted(ray.ScriptFile(script_flags))
             return
 
         for i in range(self.ui.sessionList.topLevelItemCount()):
-            item = self.ui.sessionList.topLevelItem(i)
+            item = self.ui.sessionList.topLevelItem(i) # type:ignore
             scripted_item = item.find_item_with(dir_name)
             if scripted_item is not None:
-                scripted_item.set_scripted(script_flags)
+                scripted_item.set_scripted(ray.ScriptFile(script_flags))
 
     def _resize_session_names_column(self):
         self.ui.sessionList.setColumnWidth(COLUMN_NOTES, 20)
@@ -1021,21 +1077,21 @@ class OpenSessionDialog(ChildDialog):
             self.ui.sessionList.setColumnWidth(COLUMN_DATE, 105)
 
             width = self.ui.sessionList.width() - 150
-            if scroll_bar.isVisible():
+            if scroll_bar is not None and scroll_bar.isVisible():
                 width -= scroll_bar.width()
             
             width = max(width, 20)
             
         else:
             width = self.ui.sessionList.width() - 45            
-            if scroll_bar.isVisible():
+            if scroll_bar is not None and scroll_bar.isVisible():
                 width -= scroll_bar.width()
             
             width = max(width, 40)
 
         self.ui.sessionList.setColumnWidth(COLUMN_NAME, width)
 
-    def _show_client_properties(self, client_id:str):
+    def _show_client_properties(self, client_id: str):
         for pv_client in self.session.preview_client_list:
             if pv_client.client_id == client_id:
                 properties_dialog = ClientPropertiesDialog.create(
@@ -1050,8 +1106,8 @@ class OpenSessionDialog(ChildDialog):
         if item is None:
             return
         
-        session_name = item.data(COLUMN_NAME, Qt.UserRole)
-        self.to_daemon('/ray/session/add_other_session_client',
+        session_name = item.data(COLUMN_NAME, Qt.ItemDataRole.UserRole)
+        self.to_daemon(r.session.ADD_OTHER_SESSION_CLIENT,
                        session_name, client_id)
         self.reject()
 
@@ -1064,12 +1120,12 @@ class OpenSessionDialog(ChildDialog):
 
     def closeEvent(self, event):
         self._cancel_copy_clicked()
-        ChildDialog.closeEvent(self, event)
+        return super().closeEvent(event)
 
-    def get_selected_session(self)->str:
-        if self.ui.sessionList.currentItem():
-            return self.ui.sessionList.currentItem().data(
-                COLUMN_NAME, Qt.UserRole)
+    def get_selected_session(self) -> Optional[str]:
+        current_item = self.ui.sessionList.currentItem()
+        if current_item is not None:
+            return current_item.data(COLUMN_NAME, Qt.ItemDataRole.UserRole)
 
     def want_to_save_previous(self)->bool:
         if self.ui.checkBoxSaveCurrentSession.isHidden():
