@@ -1,26 +1,51 @@
 #!/usr/bin/python3 -u
 
-#libs
+# Imports from standard library
 import signal
 import sys
-import time
+import os
+from pathlib import Path
+import logging
+from typing import TYPE_CHECKING
 
-from PyQt5.QtWidgets import QApplication
-from PyQt5.QtGui import QIcon, QFontDatabase
-from PyQt5.QtCore import QLocale, QTranslator, QTimer, QLibraryInfo
+root_path = Path(__file__).parents[2]
 
-#local imports
-from gui_tools import ArgParser, CommandLineArgs, init_gui_tools, get_code_root
+# allow libs to be imported from submodules and shared
+sys.path.insert(1, str(root_path / 'HoustonPatchbay' / 'source'))
+sys.path.insert(1, str(root_path / 'src' / 'shared'))
+
+from qt_api import QT_API
+os.environ['QT_API'] = QT_API
+
+# third party imports
+from qtpy.QtWidgets import QApplication
+from qtpy.QtGui import QIcon, QFontDatabase
+from qtpy.QtCore import QLocale, QTranslator, QTimer, QLibraryInfo, QDir, Qt
+
+# Imports from src/shared
+import ray
+from proc_name import set_proc_name
+
+# Local imports
+from gui_tools import (ArgParser, CommandLineArgs,
+                       init_gui_tools, get_code_root)
 from gui_server_thread import GuiServerThread
 from gui_session import SignaledSession
-import ray
 
+# prevent to not find icon at startup
+import resources_rc
+
+_logger = logging.getLogger()
+session = None
 
 def signal_handler(sig, frame):
+    if session is None:
+        return
+    
     if sig in (signal.SIGINT, signal.SIGTERM):
         if session.daemon_manager.launched_before:
             if (CommandLineArgs.under_nsm
-                    and session.server_status != ray.ServerStatus.OFF):
+                    and session.server_status is not ray.ServerStatus.OFF):
                 session.main_win.terminate_request = True
 
                 l_server = GuiServerThread.instance()
@@ -33,7 +58,20 @@ def signal_handler(sig, frame):
         session.main_win.terminate_request = True
         session.daemon_manager.stop()
 
-if __name__ == '__main__':
+
+if True:
+    # set logger handlers
+    _log_handler = logging.StreamHandler()
+    _log_handler.setFormatter(logging.Formatter(
+        f"%(levelname)s:%(name)s - %(message)s"))
+    _logger.addHandler(_log_handler)
+    
+    set_proc_name(ray.APP_TITLE.lower())
+    
+    resources_dir = Path(__file__).parents[2] / 'resources'
+    for prefix in 'fonts', 'scalable':
+        QDir.setSearchPaths(prefix, [str(resources_dir / prefix)])
+
     # set Qt Application
     app = QApplication(sys.argv)
     app.setApplicationName(ray.APP_TITLE)
@@ -63,17 +101,34 @@ if __name__ == '__main__':
         app.installTranslator(patchbay_translator)
 
     sys_translator = QTranslator()
-    path_sys_translations = QLibraryInfo.location(QLibraryInfo.TranslationsPath)
-    if sys_translator.load(QLocale(), 'qt', '_', path_sys_translations):
-        app.installTranslator(sys_translator)
+    if QT_API != 'PyQt5' or TYPE_CHECKING:
+        path_sys_translations = QLibraryInfo.path(
+            QLibraryInfo.LibraryPath.TranslationsPath)
+    else:
+        path_sys_translations = QLibraryInfo.location(
+            QLibraryInfo.TranslationsPath)
 
     QFontDatabase.addApplicationFont(":/fonts/Ubuntu-R.ttf")
     QFontDatabase.addApplicationFont(":/fonts/Ubuntu-C.ttf")
 
     # get arguments
     parser = ArgParser()
-
     init_gui_tools()
+    
+    log_dict = {logging.INFO: CommandLineArgs.info,
+                logging.DEBUG: CommandLineArgs.dbg}
+    
+    for log_level, multimodule in log_dict.items():
+        for module in multimodule.split(':'):
+            if not module:
+                continue
+
+            if module == 'raysession':
+                _logger.setLevel(log_level)
+                continue
+
+            _mod_logger = logging.getLogger(module)
+            _mod_logger.setLevel(log_level)
 
     # Add raysession/src/bin to $PATH
     # to can use raysession after make, without install
@@ -94,10 +149,5 @@ if __name__ == '__main__':
 
     app.exec()
 
-    # TODO find something better, sometimes program never ends without.
-    time.sleep(0.002)
-
     server.stop()
     session.quit()
-    del session
-    del app
